/*---------------------------------------------------------------------------\
| PicCore: Framework for the PIC18F458
|
| File:                 adc.h          Header for adc Code
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 02/10/2002 | Created. Again.
\---------------------------------------------------------------------------*/


#ifndef _ADC_H   // Don't include more than once (last line = #endif)
#define _ADC_H

//------------------------------------------------------------------------
// Typedefs, enums, etc.
//------------------------------------------------------------------------

enum ADC_INIT_MASK
{
   // Turn the ADC peripheral on or off.

    ADC_ENABLE_MASK     = 0b10000000,
    ADC_DISABLED        = 0b00000000,
    ADC_ENABLED         = 0b10000000,

    // Choose whether the 10bit result is left or right justified in the
    // 16bits of ADRESH:ADRESHL

    ADC_JUSTIFY_MASK    = 0b01000000,
    ADC_JUSTIFY_LEFT    = 0b00000000,
    ADC_JUSTIFY_RIGHT   = 0b01000000,

    // Choose which channel to sample (corresponding to AN0 - AN7)

    ADC_CHANNEL_MASK    = 0b00111000,
    ADC_CHANNEL_0       = 0b00000000,
    ADC_CHANNEL_1       = 0b00001000,
    ADC_CHANNEL_2       = 0b00010000,
    ADC_CHANNEL_3       = 0b00011000,
    ADC_CHANNEL_4       = 0b00100000,
    ADC_CHANNEL_5       = 0b00101000,
    ADC_CHANNEL_6       = 0b00110000,
    ADC_CHANNEL_7       = 0b00111000,

    // Choose how many pins the ADC is going to use (which forces those
    // pins to inputs not matter what the TRISx registers are set at).

    ADC_PORT_MASK       = 0b00000110,
    ADC_PORT_OFF        = 0b00000000,
    ADC_PORT_1_CH       = 0b00000010,
    ADC_PORT_3_CH       = 0b00000100,
    ADC_PORT_5_CH       = 0b00000110,

    // Choose whether to enable or disable interrupts

    ADC_INTS_MASK       = 0b00000001,
    ADC_INTS_ENABLED    = 0b00000001,
    ADC_INTS_DISABLED   = 0b00000000

};


//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// Clear the Timer2 interrupt flag

#define clear_adc_interrupt()  ADIF = 0


// Enabled and disable Timer2 interrupts and set priorities

#define disable_adc_interrupts()     ADIE = 0
#define enable_adc_interrupts()      ADIE = 1

#define set_adc_ints_low()          ADIP = 0
#define set_adc_ints_high()         ADIP = 1

#define start_adc_conversion()      GODONE = 1

//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------


void initialize_adc (enum ADC_INIT_MASK optionsMask);

#if INTS_ADC_ISR_USED == INTS_CORE_ISR_ENABLED
void adc_isr (void);
#endif

#if INTS_ADC_APPLICATION_HOOK == INTS_HOOK_ENABLED
void adc_application_handler (void);
#endif


//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

// None

#endif              // _ADC_H





