/*---------------------------------------------------------------------------\
| Project:  Generic LV2 PIC18F458 CAN node firmware
|
| File:     serial.h
|
| Descr.:   Includes for the serial.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _SERIAL_H   // Don't include more than once (last line = #endif)
#define _SERIAL_H

//------------------------------------------------------------------------
// Typedefs, enums, etc.
//------------------------------------------------------------------------

enum SERIAL_INIT_MASK
{
    SERIAL_TRANSMIT_ENABLE              = 0b10000000,
    SERIAL_TRANSMIT_DISABLE             = 0b00000000,
    SERIAL_TRANSMIT_ENABLE_INTS         = 0b01000000,
    SERIAL_TRANSMIT_DISABLE_INTS        = 0b00000000,

    SERIAL_RECEIVE_ENABLE               = 0b00010000,
    SERIAL_RECEIVE_DISABLE              = 0b00000000,
    SERIAL_RECEIVE_ENABLE_INTS          = 0b00001000,
    SERIAL_RECEIVE_DISABLE_INTS         = 0b00000000,

    SERIAL_BITRATE_9600                 = 0b00000001,
    SERIAL_BITRATE_19200                = 0b00000010
};


//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// Define FIFO circular queues for serial port transmit and receive.
// NOTE THAT THESE NUMBERS ARE THE LENGTH IN BYTES (250 bytes) AND
// NOT THE FINAL INDEX NUMBER (249).

#define SERIALTXQUEUELENGTH 120
#define SERIALRXQUEUELENGTH 120




//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------


void    InitializeSerial    (enum SERIAL_INIT_MASK optionsMask);

void    serial_tx_isr         (void);
void    serial_rx_isr         (void);

void    SendSerialByte      (uint8_t byte);
uint8_t GetSerialByte       (void);


// Writing to TXREG sends a byte out AND clears the interrupt

#define transmit_and_clear_int(byte)  TXREG = byte


// Reading RCREG gets the current byte AND clears the interrupt:

#define receive_and_clear_int()  (RCREG)


// Enabled and disable TX interrupts and set priorities

#define disable_serial_tx_ints()    TXIE = 0
#define enable_serial_tx_ints()     TXIE = 1

#define set_serial_tx_ints_low()    TXIP = 0
#define set_serial_tx_ints_high()   TXIP = 1


// Enabled and disable RX interrupts and set priorities

#define disable_serial_rx_ints()    RCIE = 0
#define enable_serial_rx_ints()     RCIE = 1

#define set_serial_rx_ints_low()    RCIP = 0
#define set_serial_rx_ints_high()   RCIP = 1

// Clear overrun errors in the receive section

#define clear_serial_rx_overrun()   CREN=0;CREN=1

//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

extern  bit serial_rx_data_available;

#endif              // _SERIAL_H





